Index: trunk/psModules/src/concepts/pmConcepts.h
===================================================================
--- trunk/psModules/src/concepts/pmConcepts.h	(revision 7469)
+++ trunk/psModules/src/concepts/pmConcepts.h	(revision 9510)
@@ -37,8 +37,17 @@
     PM_CONCEPT_SOURCE_CAMERA   = 0x01,  // Concept comes from the camera information
     PM_CONCEPT_SOURCE_DEFAULTS = 0x02,  // Concept comes from defaults
-    PM_CONCEPT_SOURCE_HEADER   = 0x04,  // Concept comes from FITS header
-    PM_CONCEPT_SOURCE_DATABASE = 0x08,  // Concept comes from database
-    PM_CONCEPT_SOURCE_ALL      = 0x0e   // All concepts
+    PM_CONCEPT_SOURCE_PHU      = 0x04,  // Concept comes from PHU
+    PM_CONCEPT_SOURCE_HEADER   = 0x08,  // Concept comes from FITS header
+    PM_CONCEPT_SOURCE_DATABASE = 0x10,  // Concept comes from database
+    PM_CONCEPT_SOURCE_ALL      = 0xff   // All concepts
 } pmConceptSource;
+
+// Read the concepts for the given set of fpa, chip, cell
+bool pmConceptsRead(pmFPA *fpa,         // FPA for which to read concepts
+                    pmChip *chip,       // Chip for which to read concepts, or NULL
+                    pmCell *cell,       // Cell for which to read concepts, or NULL
+                    pmConceptSource source, // The source of the concepts to read
+                    psDB *db            // Database handle
+                   );
 
 // Set blanks, read or write concepts at the appropriate level
